from setuptools import setup

setup(name='gallant_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions'],
      author = 'gallant decoy',
      author_email ='gallantdecoy@gmail.com',
      zip_safe=False)
